namespace Unibas.Aci.Test {

using System;
using NUnit.Framework;
using Unibas.Aci.Modello;
using Unibas.Aci.Persistenza;

[TestFixture]
public class TestDAOAutomobile {
         
    private DataSource dataSource;
    private Automobile automobile;
    private Proprietario proprietario;
    
    [SetUp]
    public void SetUp() {
        dataSource = DataSource.GetInstance();
        proprietario = new Proprietario();
        proprietario.CodiceFiscale = "cftest1";
        proprietario.Nome = "Proprietario di test";
        proprietario.CittaDiResidenza = "citta di test";
        proprietario.AnnoPatente = 2003;
        automobile = new Automobile();
        automobile.Targa = "test1";
        automobile.Modello = "Modello di test";
        automobile.Cilindrata = 2000;
    }
    
    [Test]
    public void TestInserisciAutomobile() {
        try {
            DAOProprietario.DoInsert(proprietario);
            automobile.Proprietario = proprietario;            
            DAOAutomobile.DoInsert(automobile);
            Automobile automobile1 = DAOAutomobile.DoSelectTarga("test1");
            Assert.IsNotNull(automobile1);
            Assert.AreEqual(automobile1.Targa, "test1");
            Assert.AreEqual(automobile1.Modello, "Modello di test");
            Assert.AreEqual(automobile1.Cilindrata, 2000);
        } catch (Exception e) {
            System.Console.WriteLine(e);
            Assert.Fail();
        } finally {
            try {
                DAOAutomobile.DoDelete(automobile);
                DAOProprietario.DoDelete(proprietario);
            } catch (Exception e) {
                System.Console.WriteLine(e);
            }
        }
    }
    
    
    [Test]
    public void TestCercaAutomobile() {
        try {
            DAOProprietario.DoInsert(proprietario);
            automobile.Proprietario = proprietario;
            Automobile automobile2 = DAOAutomobile.DoSelectTarga("test1");
            Assert.IsNull(automobile2);
            DAOAutomobile.DoInsert(automobile);
            automobile2 = DAOAutomobile.DoSelectTarga("test1");
            DAOAutomobile.CaricaProprietario(automobile2);
            Assert.IsNotNull(automobile2);
            Assert.AreEqual(automobile2.Targa, "test1");
            Assert.AreEqual(automobile2.Modello, "Modello di test");
            Assert.AreEqual(automobile2.Cilindrata, 2000);
            Assert.AreEqual(automobile2.Proprietario.CodiceFiscale, "cftest1");
        } catch (Exception e) {
            System.Console.WriteLine(e);
            Assert.Fail();
        } finally {
            try {
                DAOAutomobile.DoDelete(automobile);
                DAOProprietario.DoDelete(proprietario);
            } catch (Exception e) {
                System.Console.WriteLine(e);
            }
        }
    }
    
    [Test]
    public void TestAggiornaAutomobile() {
        try {
            DAOProprietario.DoInsert(proprietario);
            automobile.Proprietario = proprietario;
            DAOAutomobile.DoInsert(automobile);            
            automobile = DAOAutomobile.DoSelectTarga("test1");
            DAOAutomobile.CaricaProprietario(automobile);
            Assert.IsNotNull(automobile);
            automobile.Modello = "Nuovo modello di test";
            DAOAutomobile.DoUpdate(automobile);
            Automobile automobile1 = DAOAutomobile.DoSelectTarga("test1");
            Assert.IsNotNull(automobile1);
            Assert.AreEqual(automobile1.Targa, "test1");
            Assert.AreEqual(automobile1.Modello, "Nuovo modello di test");
            Assert.AreEqual(automobile1.Cilindrata, 2000);
        } catch (Exception e) {
            System.Console.WriteLine(e);
            Assert.Fail();
        } finally {
            try {
                DAOAutomobile.DoDelete(automobile);
                DAOProprietario.DoDelete(proprietario);
            } catch (Exception e) {
                System.Console.WriteLine(e);
            }
        }
    }

}

}
