namespace Unibas.Aci.Test {

using System;
using System.Collections;
using NUnit.Framework;
using Unibas.Aci.Modello;
using Unibas.Aci.Persistenza;

[TestFixture]
public class TestDAOProprietario {
         
    private DataSource dataSource;
    private Proprietario proprietario;
    private Proprietario proprietario2;
    private Automobile automobile;
    private Automobile automobile2;
    
    [SetUp]
    public void SetUp() {
        dataSource = DataSource.GetInstance();
        proprietario = new Proprietario();
        proprietario.CodiceFiscale = "cftest2";
        proprietario.Nome = "Proprietario di test";
        proprietario.CittaDiResidenza = "citta di test";
        proprietario.AnnoPatente = 2003;
        proprietario2 = new Proprietario();
        proprietario2.CodiceFiscale = "cftest3";
        proprietario2.Nome = "Proprietario di test";
        proprietario2.CittaDiResidenza = "citta di test";
        proprietario2.AnnoPatente = 2003;
        automobile = new Automobile();
        automobile.Targa = "test3";
        automobile.Modello = "Modello di test";
        automobile.Cilindrata = 2000;
        automobile.Proprietario = proprietario;
        automobile2 = new Automobile();
        automobile2.Targa = "test4";
        automobile2.Modello = "Modello di test";
        automobile2.Cilindrata = 2000;
        automobile2.Proprietario = proprietario;
    }
        
    [Test]
    public void TestInserisciProprietario() {
        try {
            DAOProprietario.DoInsert(proprietario);
            Proprietario proprietario1 = DAOProprietario.DoSelectCodiceFiscale("cftest2");
            Assert.IsNotNull(proprietario1);
            Assert.AreEqual(proprietario1.Nome, "Proprietario di test");
            Assert.AreEqual(proprietario1.CittaDiResidenza, "citta di test");
            Assert.AreEqual(proprietario1.AnnoPatente, 2003);
        } catch (Exception e) {
            System.Console.WriteLine(e);
            Assert.Fail();
        } finally {
            try {
                DAOProprietario.DoDelete(proprietario);
            } catch (Exception e) {
                System.Console.WriteLine(e);
            }
        }
    }
    
    [Test]
    public void TestCaricaAutomobiliProprietario() {
        try {
            DAOProprietario.DoInsert(proprietario);
            DAOAutomobile.DoInsert(automobile);
            DAOProprietario.CaricaAutomobili(proprietario);
            Assert.AreEqual(proprietario.NumeroAutomobili, 1);
            DAOAutomobile.DoInsert(automobile2);
            DAOProprietario.CaricaAutomobili(proprietario);
            Assert.AreEqual(proprietario.NumeroAutomobili, 2);
        } catch (Exception e) {
            System.Console.WriteLine(e);
            Assert.Fail();
        } finally {
            try {
                DAOAutomobile.DoDelete(automobile);
                DAOAutomobile.DoDelete(automobile2);
                DAOProprietario.DoDelete(proprietario);
            } catch (Exception e) {
                System.Console.WriteLine(e);
            }
        }
    }
    
    [Test]
    public void TestCercaPerCodiceFiscale() {
        try {
            Proprietario proprietariox = DAOProprietario.DoSelectCodiceFiscale("cftest2");
            Assert.IsNull(proprietariox);
            DAOProprietario.DoInsert(proprietario);
            proprietariox = DAOProprietario.DoSelectCodiceFiscale("cftest2");
            Assert.IsNotNull(proprietariox);
            Assert.AreEqual(proprietariox.CodiceFiscale, "cftest2");
            Assert.AreEqual(proprietariox.Nome, "Proprietario di test");
            Assert.AreEqual(proprietariox.CittaDiResidenza, "citta di test");
            Assert.AreEqual(proprietariox.AnnoPatente, 2003);
            Assert.AreEqual(proprietariox.NumeroAutomobili, 0);
        } catch (Exception e) {
            System.Console.WriteLine(e);
            Assert.Fail();
        } finally {
            try {
               DAOProprietario.DoDelete(proprietario);
            } catch (Exception e) {
                System.Console.WriteLine(e);
            }
        }
    }

    [Test]
    public void TestAggiornaProprietario() {
        try {
            DAOProprietario.DoInsert(proprietario);
            proprietario = DAOProprietario.DoSelectCodiceFiscale("cftest2");
            Assert.IsNotNull(proprietario);            
            proprietario.Nome = "Nuovo proprietario di test";
            DAOProprietario.DoUpdate(proprietario);
            Proprietario proprietario1 = DAOProprietario.DoSelectCodiceFiscale("cftest2");
            Assert.IsNotNull(proprietario1);
            Assert.AreEqual(proprietario1.Nome, "Nuovo proprietario di test");
            Assert.AreEqual(proprietario1.CittaDiResidenza, "citta di test");
            Assert.AreEqual(proprietario1.AnnoPatente, 2003);
        } catch (Exception e) {
            System.Console.WriteLine(e);
            Assert.Fail();
        } finally {
            try {
                DAOProprietario.DoDelete(proprietario);
            } catch (Exception e) {
                System.Console.WriteLine(e);
            }
        }
    }
    
    [Test]
    public void TestCercaPerNome() {
        try {
            IList listaProprietari = DAOProprietario.DoSelectNome("Proprietario di test");
            Assert.AreEqual(listaProprietari.Count, 0);
            DAOProprietario.DoInsert(proprietario);
            listaProprietari = DAOProprietario.DoSelectNome("Proprietario di test");
            Assert.AreEqual(listaProprietari.Count, 1);
            DAOProprietario.DoInsert(proprietario2);
            listaProprietari = DAOProprietario.DoSelectNome("Proprietario di test");
            Assert.AreEqual(listaProprietari.Count, 2);
        } catch (Exception e) {
            System.Console.WriteLine(e);
            Assert.Fail();
        } finally {
            try {
                DAOProprietario.DoDelete(proprietario);
                DAOProprietario.DoDelete(proprietario2);
            } catch (Exception e) {
                System.Console.WriteLine(e);
            }
        }
    }
    
    
}

}
